pub struct ContractExecutableRef {
pub owner: Address,
pub tag: String,
}Expand description
Executable referenced via a persistent storage entry owned by a contract, either this contract or another contract.
The persistent storage entry owned by the owner has the tag as its key.
Fields
owner: Addresstag: StringImplementations