Module token

Module token 

Token contains types for calling and accessing token contracts, including the Stellar Asset Contract.

See TokenInterface for the interface of token contracts such as the Stellar Asset Contract.

Use TokenClient for calling token contracts such as the Stellar Asset Contract.

Structs

StellarAssetArgs
StellarAssetArgs is a type for building arg lists for functions defined in “StellarAssetInterface”.
StellarAssetClient
StellarAssetClient is a client for calling the contract defined in “StellarAssetInterface”.
StellarAssetFnSpec
TokenArgs
TokenArgs is a type for building arg lists for functions defined in “TokenInterface”.
TokenClient
TokenClient is a client for calling the contract defined in “TokenInterface”.
TokenFnSpec

Traits

StellarAssetInterface
Interface for admin capabilities for Token contracts, such as the Stellar Asset Contract.
TokenInterface
Interface for Token contracts, such as the Stellar Asset Contract.